@@ -6,11 +6,11 @@
 #include "mixedlettersmodewidget.h"
 #include "ui_practice_widget_written.h"
 
+#include <KColorScheme>
+#include <KRandom>
 #include <QFontMetrics>
 #include <QPainter>
-
-#include <KColorScheme>
-
+#include <QRandomGenerator>
 
 using namespace Practice;
 
@@ -21,13 +21,13 @@ MixedLettersModeWidget::MixedLettersModeWidget(GuiFrontend *frontend, QWidget *p
     connect(m_ui->answerEdit, &QLineEdit::textChanged, this, &MixedLettersModeWidget::updatePixmap);
 }
 
-void MixedLettersModeWidget::setSolutionFont(const QFont& font)
+void MixedLettersModeWidget::setSolutionFont(const QFont &font)
 {
     m_solutionFont = font;
     WrittenPracticeWidget::setSolutionFont(font);
 }
 
-void MixedLettersModeWidget::setQuestion(const QVariant& question)
+void MixedLettersModeWidget::setQuestion(const QVariant &question)
 {
     m_question = question.toString();
     WrittenPracticeWidget::setQuestion(question);
@@ -54,7 +54,7 @@ void MixedLettersModeWidget::updatePixmap()
     defaultPen.setColor(palette().color(QPalette::WindowText));
     QString enteredChars = m_ui->answerEdit->text();
     int i = 0;
-    Q_FOREACH(QChar ch, m_mixedSolution) {
+    for (QChar ch : qAsConst(m_mixedSolution)) {
         int pos = enteredChars.indexOf(ch);
         if (pos != -1) {
             p.setPen(scheme.foreground(KColorScheme::InactiveText).color());
@@ -62,26 +62,26 @@ void MixedLettersModeWidget::updatePixmap()
         } else {
             p.setPen(defaultPen);
         }
-        p.drawText(charWidth + charWidth * i * 2, charHeight + int(m_positions.at(i)*charHeight * 0.25), ch);
+        p.drawText(charWidth + charWidth * i * 2, charHeight + int(m_positions.at(i) * charHeight * 0.25), ch);
         i++;
     }
     m_ui->mixedSolutionLabel->setPixmap(m_pixmap);
     m_ui->mixedSolutionLabel->setMinimumSize(m_pixmap.size());
 }
 
-void MixedLettersModeWidget::setSolution(const QVariant& solution)
+void MixedLettersModeWidget::setSolution(const QVariant &solution)
 {
     WrittenPracticeWidget::setSolution(solution);
     m_solution = solution.toString();
     QList<QChar> chars;
-    Q_FOREACH(QChar ch, solution.toString()) {
+    for (QChar ch : qAsConst(m_solution)) {
         chars.append(ch);
     }
-    m_randomSequence.randomize(chars);
+    KRandom::shuffle(chars);
     m_mixedSolution.clear();
     m_positions.clear();
-    Q_FOREACH(QChar ch, chars) {
+    for (QChar ch : qAsConst(chars)) {
         m_mixedSolution.append(ch);
-        m_positions.append(m_randomSequence.getInt(8));
+        m_positions.append(QRandomGenerator::global()->bounded(8));
     }
 }
